( cd usr/lib64 ; rm -rf libgaim-remote.so.0 )
( cd usr/lib64 ; ln -sf libgaim-remote.so.0.0.0 libgaim-remote.so.0 )
( cd usr/lib64 ; rm -rf libgaim-remote.so )
( cd usr/lib64 ; ln -sf libgaim-remote.so.0.0.0 libgaim-remote.so )
